"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.autoBind = void 0;
/**
 * @author 田尘殇Sean(sean.snow@live.com) create at 2018/7/16
 */
const excludeFunc = [
    'constructor',
    'render',
    'componentWillMount',
    'componentDidMount',
    'componentWillReceiveProps',
    'shouldComponentUpdate',
    'componentWillUpdate',
    'componentDidUpdate',
    'componentWillUnmount'
];
function autoBind(...args) {
    if (args.length === 1) {
        return bindClass(args[0]);
    }
    else {
        return bindMethod(args[0], args[1], args[2]);
    }
}
exports.autoBind = autoBind;
function bindClass(target) {
    let keys;
    if (typeof Reflect !== 'undefined' && typeof Reflect.ownKeys === 'function') {
        keys = Reflect.ownKeys(target.prototype);
    }
    else {
        keys = Object.getOwnPropertyNames(target.prototype);
        if (typeof Object.getOwnPropertySymbols === 'function') {
            keys = keys.concat(Object.getOwnPropertySymbols(target.prototype));
        }
    }
    keys.filter(key => !excludeFunc.includes(key)).forEach(key => {
        let descriptor = Object.getOwnPropertyDescriptor(target.prototype, key);
        if (typeof descriptor.value === 'function') {
            Object.defineProperty(target.prototype, key, bindMethod(target, key, descriptor));
        }
    });
    return target;
}
function bindMethod(target, key, descriptor) {
    let fn = descriptor.value;
    if (typeof fn !== 'function') {
        throw new Error(`@autobind decorator can only be applied to methods not: ${typeof fn}`);
    }
    let definingProperty = false;
    return {
        configurable: true,
        get() {
            if (definingProperty || this === target.prototype || this.hasOwnProperty(key)
                || typeof fn !== 'function') {
                return fn;
            }
            let boundFn = fn.bind(this);
            definingProperty = true;
            Object.defineProperty(this, key, {
                configurable: true,
                get() {
                    return boundFn;
                },
                set(value) {
                    fn = value;
                    delete this[key];
                }
            });
            definingProperty = false;
            return boundFn;
        },
        set(value) {
            fn = value;
        }
    };
}
